/*
 * Vencord, a Discord client mod
 * Copyright (c) 2024 Vendicated and contributors
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

import "./style.css";

import { Devs } from "@utils/constants";
import definePlugin, { PluginNative } from "@utils/types";
import { Alerts, TextInput } from "@webpack/common";

import UserpluginInstallButton from "./UserpluginInstallButton";

export const plugins: any[] = [];
export const CLONE_LINK_REGEX = /https:\/\/((?:git(?:hub|lab)\.com|git\.(?:[a-zA-Z0-9]|\.)+|codeberg\.org))\/(?!user-attachments)((?:[a-zA-Z0-9]|-)+)\/((?:[a-zA-Z0-9]|-)+)(?:\.git)?(?:\/)?/;


// @ts-ignore
export const Native = VencordNative.pluginHelpers.UserpluginInstaller as PluginNative<typeof import("./native")>;

export default definePlugin({
    name: "UserpluginInstaller",
    description: "Install userplugins with a simple button click",
    authors: [Devs.nin0dev],
    renderMessageAccessory: (props) => {
        return <UserpluginInstallButton props={props} />;
    },
    toolboxActions: {
        "Install Plugin": () => {
            let gitUrl = "";
            Alerts.show({
                title: "Install plugin",
                body: <>
                    <TextInput onChange={v => { gitUrl = v; }} placeholder="Git link (https://github.com/...)" />
                </>,
                confirmText: "Install",
                async onConfirm() {
                    const gitLink = gitUrl.match(CLONE_LINK_REGEX)!;
                    await Native.initPluginInstall(gitLink[0], gitLink[1], gitLink[2], gitLink[3]);
                    window.location.reload();
                }
            });
        },
        "Uninstall Plugin": () => {

        }
    }
});
